/*-
# MS WINDOWS-BASED ABACUS
#
#  wabacus.h
#
###
#
#  Copyright (c) 1996 - 2006	David Albert Bagley, bagleyd@tux.org
#
#                   All Rights Reserved
#
#  Permission to use, copy, modify, and distribute this software and
#  its documentation for any purpose and without fee is hereby granted,
#  provided that the above copyright notice appear in all copies and
#  that both that copyright notice and this permission notice appear in
#  supporting documentation, and that the name of the author not be
#  used in advertising or publicity pertaining to distribution of the
#  software without specific, written prior permission.
#
#  This program is distributed in the hope that it will be "useful",
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
*/

/* Header file for wabacus.c */

#define IDM_EXIT	101
#define IDM_HIDE	102
#define IDM_CLEAR	200
#define IDM_INCREMENT	201
#define IDM_DECREMENT	202
#define IDM_FORMAT	203
#define IDM_ROMANNUMERAL	204
#define IDM_SIGN	205
#define IDM_QUARTER	206
#define IDM_QUARTERPERCENT	207
#define IDM_TWELFTH	208
#define IDM_ANOMALY	209
#define IDM_WATCH	210
#define IDM_SPEED	211
#define IDM_SLOW	212
#define IDM_SOUND	213
#define IDM_DEMO	300
#define IDM_NEXT	301
#define IDM_REPEAT	302
#define IDM_MORE	303
#define IDM_ABOUT	400
#define IDM_DESCRIPTION	401
#define IDM_FEATURES	402
#define IDM_REFERENCES	403
